/* $Id: path.h,v 1.2 1998/02/19 01:59:14 svmcguir Exp $ */

typedef struct{
  /* pathParams structure
   *
   * Public.  These should be used outside the path* files.
   * Covariances and growth rates are per period (timeslice).
   *
   * underliers:	The number of underliers.
   *
   * covariance[i][j]	The covariance between underlier i and underlier j.
   *
   * growthRate[i]	The expected rate of return on underlier i.  In general
   *			the will all equal the risk free interest rate.
   * dividendRate[i]	The dividend rate on underlier i.
   *
   * phrase		A string which will be used to generate seeds for the
   * 			random number generator.
   * paths		The number of paths.
   *
   * times		The number of timeslices.
   *
   * price[t][p][u]	The price of underlier u on path p at time t.  After
   *			memory allocation, the initial prioces should be placed
   *			in price[0][p][u].
   *
   * clusterSize	The number of paths in a cluster.
   *
   * clusterVariance	Variance around central path in cluster.
   */

  long underliers;
  double **covariance;
  double *growthRate;
  double *dividendRate;
  char phrase[100];
  int paths;
  int times;
  double ***price;
  int clusterSize;
  double clusterVariance;
  int meshPaths;

  /* Private.  These should not be used outside the path* files.
   * These are for the use of the RANLIB library.  Scratch and
   * parm are floats because that is what RANLIB works with.
   *
   * seed1,seed2	Seeds for the random number generator derived from
   *			phrase.
   * cov1		RANLIB wants the covariances in a one dimensional array
   *			that will be this.
   * fgrowth		Float version of the growthRate array.
   *
   * parm		RANLIB requires a float array of size d(d+3)/2 +1 (where
   *			d is the number of dimensions) for internal stuff.
   */

  long seed1, seed2;
  float *parm, *cov1, *fgrowth;
}pathData;



void pathParamsAllocate(pathData *pp);
void pathDataAllocate(pathData *pd);
void pathParamsInit(pathData *pp);
void pathDataFill(pathData *pd);
double pathTransitionProb(pathData *pp, int time, int initialPath, int finalPath);
